%global bashcompletion_dir %(pkg-config --variable=completionsdir bash-completion 2> /dev/null || :)

%global vagrant_spec_commit 708be5c53ea10131b19921c536eae012d1396a96

%bcond_without help2man

Name: vagrant
Version: 2.3.7
Release: %mkrel 2
Summary: Build and distribute virtualized development environments
Group: Development/Other
License: MIT
URL: https://vagrantup.com/
Source0: https://github.com/hashicorp/%{name}/archive/refs/tags/v%{version}.tar.gz
# Upstream binstub with adjusted paths, the offical way how to run vagrant
Source1: binstub
# The library has no official release yet. But since it is just test
# dependency, it should be fine to include the source right here.
# wget https://github.com/hashicorp/vagrant-spec/archive/708be5c53ea10131b19921c536eae012d1396a96/vagrant-spec-708be5c53ea10131b19921c536eae012d1396a96.tar.gz
Source2: https://github.com/hashicorp/%{name}-spec/archive/%{vagrant_spec_commit}/%{name}-spec-%{vagrant_spec_commit}.tar.gz

# RPM macros for vagrant
Source3: macros.vagrant

# Fix build in iurt
# A test assumes we don't have permissions on / but it seems we do in iurt
# so change it to use /root.
Patch100: vagrant-2.2.19-use-root-for-inaccessible-path.patch

%{load:%{SOURCE3}}

Requires: ruby(release)
Requires: ruby(rubygems) >= 1.3.6
# Explicitly specify MRI, since Vagrant does not work with JRuby ATM.
Requires: ruby
Requires: rubygem(hashicorp-checkpoint) >= 0.1.5
Requires: rubygem(childprocess) >= 0.5.0
Requires: rubygem(erubi)
Requires: rubygem(i18n) >= 1.8
Requires: rubygem(i18n) < 2.0
Requires: rubygem(json)
Requires: rubygem(listen) >= 3.2
Requires: rubygem(listen) < 4
Requires: rubygem(log4r) >= 1.1.9
Requires: rubygem(net-ftp) >= 0.2
Requires: rubygem(net-ssh) >= 5.2.0
Requires: rubygem(net-scp) >= 1.2.0
Requires: rubygem(net-sftp) >= 2.1
Requires: rubygem(rest-client) >= 1.6.0
Requires: rubygem(rubyzip) >= 1.1.7
Requires: rubygem(googleapis-common-protos-types)
Requires: rubygem(grpc)
Requires: rubygem(rgl)
Requires: rubygem(vagrant_cloud)
Requires: bsdtar
Requires: curl

Recommends: vagrant(vagrant-libvirt)
Recommends: rubygem(bcrypt_pbkdf)
Recommends: rubygem(ed25519)
#Recommends: (podman-docker if podman)

BuildRequires: bsdtar
BuildRequires: ruby
BuildRequires: ruby-devel
BuildRequires: rubygem(listen)
BuildRequires: rubygem(childprocess)
BuildRequires: rubygem(hashicorp-checkpoint)
BuildRequires: rubygem(log4r)
BuildRequires: rubygem(net-ssh)
BuildRequires: rubygem(net-scp)
BuildRequires: rubygem(i18n)
BuildRequires: rubygem(json)
BuildRequires: rubygem(erubi)
BuildRequires: rubygem(rspec)
BuildRequires: rubygem(rspec-its)
BuildRequires: rubygem(net-sftp)
BuildRequires: rubygem(oauth)
BuildRequires: rubygem(rest-client)
BuildRequires: rubygem(rubyzip)
BuildRequires: rubygem(thor)
BuildRequires: rubygem(webmock)
BuildRequires: rubygem(webrick)
BuildRequires: rubygem(fake_ftp)
BuildRequires: rubygem(vagrant_cloud)
BuildRequires: rubygem(bigdecimal)
BuildRequires: rubygem(rake)
BuildRequires: rubygem(net-ftp)  >= 0.2
BuildRequires: rubygem(googleapis-common-protos-types)
BuildRequires: rubygem(grpc)
BuildRequires: rubygem(rgl)
BuildRequires: pkgconfig(bash-completion)
%if %{with help2man}
BuildRequires: help2man
%endif
BuildRequires: openssh-clients
BuildArch: noarch

# vagrant-atomic was retired in F26, since it was merged into Vagrant.
# https://github.com/projectatomic/vagrant-atomic/issues/5
# https://github.com/mitchellh/vagrant/pull/5847
Obsoletes: vagrant-atomic <= 0.1.0-4

# Since Vagrant itself is installed on the same place as its plugins
# the vagrant_plugin macros can be reused in the spec file, but the plugin
# name must be specified.
%global vagrant_plugin_name vagrant

%description
Vagrant is a tool for building and distributing virtualized development
environments.

%package doc
Summary: Documentation for %{name}
Group:   Documentation
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Documentation for %{name}.

%prep
%autosetup -b2 -p1

perl -pi -e 's|"~> 0.5.10"|">= 0.5.10"|' vagrant.gemspec
# childprocess
perl -pi -e 's|"~> 4.1.0"|">= 4.1.0"|' vagrant.gemspec
# rubyzip
perl -pi -e 's|"~> 2.3.2"|">= 2.3.2"|' vagrant.gemspec

%build
# installed but not yet detected
#%gemspec_remove_dep -s %{name}.gemspec -g vagrant_cloud

# Expand required Ruby compatibility, otherwise RubyGems throws exceptions.
# Relevant rhbz: https://bugzilla.redhat.com/show_bug.cgi?id=2053476#c0
# Relevant RubyGems issue: https://github.com/rubygems/rubygems/issues/4338
#sed -i -e '/required_ruby_version/ s/, "< 3.1"//' %{name}.gemspec

# Remove Windows specific dependencies
%gemspec_remove_dep -s %{name}.gemspec -g wdm
%gemspec_remove_dep -s %{name}.gemspec -g winrm
%gemspec_remove_dep -s %{name}.gemspec -g winrm-fs
%gemspec_remove_dep -s %{name}.gemspec -g winrm-elevated

# Remove BSD dependency
%gemspec_remove_dep -s %{name}.gemspec -g rb-kqueue

# Remove optional dependencies
%gemspec_remove_dep -s %{name}.gemspec -g ed25519
%gemspec_remove_dep -s %{name}.gemspec -g bcrypt_pbkdf

# Load missing dependency Vagrant::Util::MapCommandOptions
# https://github.com/hashicorp/vagrant/pull/11609
#sed -i '/^\s*require..vagrant.util.experimental.\s*$/ a\require "vagrant/util/map_command_options"' \
  #plugins/kernel_v2/config/vm.rb

gem build %{name}.gemspec

gem install -V --local \
  --no-user-install \
  --install-dir .%{vagrant_plugin_dir} \
  --bindir .%{vagrant_plugin_dir}/bin \
  --ignore-dependencies --force --no-document --backtrace \
  %{name}-%{version}.gem


%install
mkdir -p %{buildroot}%{vagrant_plugin_dir}
cp -pa .%{vagrant_plugin_dir}/* \
        %{buildroot}%{vagrant_plugin_dir}/

find %{buildroot}%{vagrant_plugin_dir}/bin -type f | xargs chmod a+x

# Provide executable similar to upstream:
# https://github.com/mitchellh/vagrant-installers/blob/master/substrate/modules/vagrant_installer/templates/vagrant.erb
install -D -m 755 %{SOURCE1} %{buildroot}%{_bindir}/vagrant
sed -i 's|@vagrant_embedded_dir@|%{vagrant_embedded_dir}|' %{buildroot}%{_bindir}/vagrant

# auto-completion
install -D -m 0644 %{buildroot}%{vagrant_plugin_instdir}/contrib/bash/completion.sh \
  %{buildroot}%{bashcompletion_dir}/%{name}
sed -i '/#!\// d' %{buildroot}%{bashcompletion_dir}/%{name}

# RPM macros
install -D -m 0644 %{SOURCE3} %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

# Create configuration directory.
install -d -m 755 %{buildroot}%{vagrant_plugin_conf_dir}
# Make sure the plugins.json exists and provide the link to
# VAGRANT_INSTALLER_EMBEDDED_DIR so Vagrant can locate the file.
touch %{buildroot}%{vagrant_plugin_conf}
ln -s -t %{buildroot}%{vagrant_embedded_dir}/ %{vagrant_plugin_conf}

%if %{with help2man}
# Turn `vagrant --help` into man page.
export GEM_PATH="%{gem_dir}:%{buildroot}/usr/share/vagrant/gems"
# Needed to display help page without a warning.
export VAGRANT_INSTALLER_ENV=1
mkdir -p %{buildroot}%{_mandir}/man1
help2man -N -s1 -o %{buildroot}%{_mandir}/man1/%{name}.1 \
    %{buildroot}/usr/share/%{name}/gems/gems/%{name}-%{version}/bin/%{name} || \
    %{buildroot}/usr/share/%{name}/gems/gems/%{name}-%{version}/bin/%{name}
%endif

%check
# Do not load dependencies from gemspec
sed -i '/^\s*context "when vagrant specification is not found" do$/,/^    end$/ s/^/#/' \
  test/unit/vagrant/bundler_test.rb
sed -i '/^\s*it "should init the bundler instance with plugins" do$/,/^    end$/ s/^/#/' \
  test/unit/vagrant/plugin/manager_test.rb

# Adjust the vagrant-spec directory name.
rm -rf ../vagrant-spec
mv ../vagrant-spec{-%{vagrant_spec_commit},}

# Remove the git reference, which is useless in our case.
sed -i '/git/ s/^/#/' ../vagrant-spec/vagrant-spec.gemspec

# Relax the dependencies, since Mageia ships with newer versions.
#sed -i '/thor/ s/~>/>=/' ../vagrant-spec/vagrant-spec.gemspec
#sed -i '/rspec/ s/~>/>=/' ./vagrant.gemspec
#sed -i '/rspec/ s/~>/>=/' ../vagrant-spec/vagrant-spec.gemspec
#sed -i '/childprocess/ s/~>/>=/' ../vagrant-spec/vagrant-spec.gemspec

#Insert new test dependencies
sed -i '25 i\  spec.add_dependency "webmock"' ../vagrant-spec/vagrant-spec.gemspec
sed -i '26 i\  spec.add_dependency "fake_ftp"' ../vagrant-spec/vagrant-spec.gemspec

# TODO: winrm is not in Mageia yet.
rm -rf test/unit/plugins/communicators/winrm
sed -i '/it "eager loads WinRM" do/,/^      end$/ s/^/#/' test/unit/vagrant/machine_test.rb
sed -i '/it "should return the specified communicator if given" do/,/^    end$/ s/^/#/' test/unit/vagrant/machine_test.rb
sed -i '/^    context "with winrm communicator" do$/,/^    end$/ s/^/#/' \
  test/unit/plugins/provisioners/ansible/provisioner_test.rb

# Disable test that requires bundler
# https://github.com/hashicorp/vagrant/issues/9273
mv test/unit/vagrant/util/env_test.rb{,.disable}

rm -r test/unit/plugins/commands/cloud

# fake_ftp 0.3.0 compatibility.
# https://github.com/livinginthepast/fake_ftp/pull/56
sed -i '/^\s*it "adds from FTP URL" do$/ a skip' test/unit/vagrant/action/builtin/box_add_test.rb

# Disable test that requires network
sed -i '/^    it "generates a network name and configuration" do$/,/^    end/ s/^/#/' \
  test/unit/plugins/providers/docker/action/prepare_networks_test.rb

# There are some Ruby 2.7 incompatibilities which might be fixed by:
# https://github.com/hashicorp/vagrant/pull/11459
# but workarond the offending test case for now.
#sed -i "/describe '#create' do/,/^  end$/ s/^/#/" \
  #test/unit/plugins/providers/docker/driver_compose_test.rb
#sed -i "/it 'removes the container' do/a\        skip 'Ruby 2.7 incompatibility'" \
  #test/unit/plugins/providers/docker/driver_compose_test.rb

# Remove failing BSD-host tests, as we don't care about those.
rm -rf test/unit/plugins/hosts/bsd

# Disable broken test for installing docker on host
# https://github.com/hashicorp/vagrant/issues/11606
sed -i '/^\s*it "installs docker if not present" do$/ a\ skip "GH#11606"' \
  test/unit/plugins/provisioners/docker/installer_test.rb

# Disable test for Home directory if building as root in a Container e.g. won't work
sed -i '/^\s*it "throws an exception if inaccessible"/, /^    end/ s/^/#/'\
  test/unit/vagrant/environment_test.rb

# Disable tests failing on class variable access from toplevel
# > Failure/Error: @@logger = nil
# https://github.com/hashicorp/vagrant/issues/12362
mv test/unit/plugins/synced_folders/unix_mount_helpers_test.rb{,.disable}

# Disable currently broken powershell tests, due to:
# https://github.com/hashicorp/vagrant/commit/5967a23fa097e89726d335dcf781ae43cb256bc1#
# https://github.com/hashicorp/vagrant/issues/12363
mv test/unit/vagrant/util/powershell_test.rb{,.disable}

# Export the OS as an environment variable that Vagrant can access, so the
# test suite is executed with same host it will be run (also avoids docker
# installer_test issue).
export VAGRANT_DETECTED_OS="$(uname -s 2>/dev/null)"

# Put gem load path on top of the load path, so they are loaded earlier then
# their StdLib symlinks.
%{!?buildtime_libdir:%global buildtime_libdir $(ruby -rrbconfig -e 'puts RbConfig::CONFIG["libdir"]')}

RUBYOPT="-I"
for module in \
    openssl \
    psych
do
    for dir in \
        %{gem_dir}/gems/$module-*/lib \
        %{buildtime_libdir}/gems/ruby/$module-*
    do
        RUBYOPT="$RUBYOPT:$dir"
    done
done
export RUBYOPT

# Allow ruby to find vagrant gem just built
export GEM_PATH="%{gem_dir}:%{buildroot}/usr/share/vagrant/gems"
# Rake solves the requires issues for tests
rake -f tasks/test.rake test:unit \
  | tee error.log

# Temporarily disable (3) tests failing on older childprocess
# 4) Vagrant::Util::Subprocess#running? should return false when subprocess has completed
#    Failure/Error: expect(sp.running?).to be(false)
#      expected false
#           got true
#    # ./test/unit/vagrant/util/subprocess_test.rb:123:in `block (4 levels) in <top (required)>'
#    # ./test/unit/vagrant/util/subprocess_test.rb:120:in `each'
#    # ./test/unit/vagrant/util/subprocess_test.rb:120:in `block (3 levels) in <top (required)>'
#    # /usr/share/gems/gems/webmock-3.11.1/lib/webmock/rspec.rb:37:in `block (2 levels) in <top (required)>'
# 5) Vagrant::Util::Subprocess#stop when subprocess has already completed should return false
#    Failure/Error: expect(sp.stop).to be(false)
#      expected false
#           got true
#    # ./test/unit/vagrant/util/subprocess_test.rb:152:in `block (5 levels) in <top (required)>'
#    # ./test/unit/vagrant/util/subprocess_test.rb:149:in `each'
#    # ./test/unit/vagrant/util/subprocess_test.rb:149:in `block (4 levels) in <top (required)>'
#    # /usr/share/gems/gems/webmock-3.11.1/lib/webmock/rspec.rb:37:in `block (2 levels) in <top (required)>'
# 6) Vagrant::Util::Subprocess#stop when subprocess is running should stop the process
#    Failure/Error: expect(sp.running?).to be(false)
#      expected false
#           got true
#    # ./test/unit/vagrant/util/subprocess_test.rb:172:in `block (5 levels) in <top (required)>'
#    # ./test/unit/vagrant/util/subprocess_test.rb:168:in `each'
#    # ./test/unit/vagrant/util/subprocess_test.rb:168:in `block (4 levels) in <top (required)>'
#    # /usr/share/gems/gems/webmock-3.11.1/lib/webmock/rspec.rb:37:in `block (2 levels) in <top (required)>'
# Note: failures will dissapear when rubygem-childprocess update PR is merged
# https://src.fedoraproject.org/rpms/rubygem-childprocess/pull-request/2/
grep -E ', (3|0) failures, ' error.log || exit 1

%if %{with help2man}
# Check `--help` output, using which man page is created
export VAGRANT_INSTALLER_ENV=1
%{buildroot}/usr/share/%{name}/gems/gems/%{name}-%{version}/bin/%{name} --help 2>/dev/null \
  | grep -q '^Usage: vagrant '
%endif

%post -p %{_bindir}/ruby
begin
  $LOAD_PATH.unshift "%{vagrant_dir}/lib"
  begin
    require "vagrant/plugin/manager"
  rescue LoadError => e
    raise
  end;

  unless File.exist?("%{vagrant_plugin_conf_link}")
    Vagrant::Plugin::StateFile.new(Pathname.new(File.expand_path "%{vagrant_plugin_conf}")).save!
    File.symlink "%{vagrant_plugin_conf}", "%{vagrant_plugin_conf_link}"
  end
rescue => e
  puts "Vagrant plugin.json is not properly initialized: #{e}"
end

%transfiletriggerin -p %{_bindir}/ruby -- %{dirname:%{vagrant_plugin_spec}}/
begin
  $LOAD_PATH.unshift "%{vagrant_dir}/lib"
  begin
    require "vagrant/plugin/manager"
  rescue LoadError => e
    raise
  end

  $stdin.each_line do |gemspec_file|
    next if gemspec_file =~ /\/%{name}-%{version}.gemspec$/

    spec = Gem::Specification.load(gemspec_file.strip)
    Vagrant::Plugin::StateFile.new(Pathname.new(File.expand_path "%{vagrant_plugin_conf_link}")).add_plugin spec.name
  end
rescue => e
  puts "Vagrant plugin register error: #{e}"
end

%transfiletriggerun -p %{_bindir}/ruby -- %{dirname:%{vagrant_plugin_spec}}/
begin
  $LOAD_PATH.unshift "%{vagrant_dir}/lib"
  begin
    require "vagrant/plugin/manager"
  rescue LoadError => e
    raise
  end

  $stdin.each_line do |gemspec_file|
    next if gemspec_file =~ /\/%{name}-%{version}.gemspec$/

    spec = Gem::Specification.load(gemspec_file.strip)
    Vagrant::Plugin::StateFile.new(Pathname.new(File.expand_path "%{vagrant_plugin_conf_link}")).remove_plugin spec.name
  end
rescue => e
  puts "Vagrant plugin un-register error: #{e}"
end

%files
# Explicitly include Vagrant plugins directory strucure to avoid accidentally
# packaged content.
%dir %{vagrant_embedded_dir}
%dir %{vagrant_plugin_dir}
%dir %{vagrant_plugin_dir}/bin
%dir %{vagrant_plugin_dir}/build_info
%dir %{dirname:%{vagrant_plugin_cache}}
%dir %{dirname:%{vagrant_plugin_docdir}}
%dir %{vagrant_plugin_dir}/extensions
%dir %{dirname:%{vagrant_plugin_instdir}}
%dir %{dirname:%{vagrant_plugin_spec}}

%{_bindir}/%{name}
%dir %{vagrant_plugin_instdir}
%license %{vagrant_plugin_instdir}/LICENSE
%doc %{vagrant_plugin_instdir}/README.md
%{vagrant_plugin_dir}/bin/vagrant
%{vagrant_plugin_dir}/extensions/*/*/%{name}-%{version}/*
%exclude %{vagrant_plugin_instdir}/.*
%exclude %{vagrant_plugin_instdir}/Vagrantfile
%{vagrant_plugin_instdir}/bin
# TODO: Make more use of contribs.
%{vagrant_plugin_instdir}/contrib
%exclude %{vagrant_plugin_instdir}/contrib/bash
# This is not the original .gemspec.
%exclude %{vagrant_plugin_instdir}/vagrant.gemspec
%{vagrant_plugin_instdir}/keys
%{vagrant_plugin_instdir}/lib
%{vagrant_plugin_instdir}/plugins
%exclude %{vagrant_plugin_instdir}/scripts
%{vagrant_plugin_instdir}/templates
%{vagrant_plugin_instdir}/version.txt
%{vagrant_plugin_instdir}/Dockerfile
%{vagrant_plugin_instdir}/Makefile
%{vagrant_plugin_instdir}/binstubs
%{vagrant_plugin_instdir}/ext
%{vagrant_plugin_instdir}/flake.*
%{vagrant_plugin_instdir}/*.go
%{vagrant_plugin_instdir}/go.*
%{vagrant_plugin_instdir}/nix
%{vagrant_plugin_instdir}/shell.nix
%{vagrant_plugin_instdir}/vagrant-config.hcl
%exclude %{vagrant_plugin_cache}
%{vagrant_plugin_spec}
%dir %{vagrant_plugin_conf_dir}
%ghost %{vagrant_plugin_conf_link}
%ghost %{vagrant_plugin_conf}
# TODO: This is suboptimal and may break, but can't see much better way ...
%dir %{dirname:%{bashcompletion_dir}}
%{_rpmconfigdir}/macros.d/macros.%{name}
%dir %{bashcompletion_dir}
%{bashcompletion_dir}/%{name}
%if %{with help2man}
%{_mandir}/man1/%{name}.1*
%endif

%files doc
%doc %{vagrant_plugin_instdir}/RELEASE.md
%doc %{vagrant_plugin_instdir}/CHANGELOG.md
%{vagrant_plugin_instdir}/Gemfile
%{vagrant_plugin_instdir}/Rakefile
%{vagrant_plugin_instdir}/tasks
%{vagrant_plugin_instdir}/vagrant-spec.config.example.rb




%changelog
* Tue Feb 04 2025 papoteur <papoteur> 2.3.7-2.mga10
+ Revision: 2145117
- fix build
- use autosetup instead of patch
- relax requirements on module rubyzip and childprocess
+ daviddavid <daviddavid>
- add missing runtime dependencies on ruby-googleapis-common-protos-types,
  ruby-grpc, ruby-rgl and ruby-vagrant_cloud (mga#33096)

* Mon Jul 03 2023 bcornec <bcornec> 2.3.7-1.mga9
+ Revision: 1963550
- Update to vagrant 2.3.7 with all files
- Update to vagrant 2.3.7

* Fri Dec 23 2022 pterjan <pterjan> 2.2.19-1.mga9
+ Revision: 1926190
- Fix build under iurt
- Sync with Fedora and tweak a bit to get it to build
- Fix syntax for recent rpm
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jan 01 2021 neoclust <neoclust> 2.2.9-1.mga8
+ Revision: 1667794
- New version 2.2.9
+ danf <danf>
- Switch URLs from http: to https:

* Fri Oct 05 2018 pterjan <pterjan> 2.0.4-1.mga7
+ Revision: 1317822
- Ignore test failures
- Update to 2.0.4
- Add missing BuildRequires
- Mageia 7 Mass Rebuild
- Add missing BuildRequires
+ daviddavid <daviddavid>
- new version: 2.0.3

* Wed Jan 24 2018 shlomif <shlomif> 2.0.1-1.mga7
+ Revision: 1196701
- New version 2.0.1 (MGA#22114).

* Tue Sep 12 2017 neoclust <neoclust> 1.9.8-1.mga7
+ Revision: 1153175
- New version 1.9.8
- New version 1.9.1
- imported package vagrant


* Fri Jul 29 2016 Vít Ondruch <vondruch@redhat.com> - 1.8.5-1
- Update to Vagrant 1.8.5.

* Mon Jul 18 2016 Jun Aruga <jaruga@redhat.com> - 1.8.1-3
- Support rest-client 2.x (rhbz#1356650).

* Mon May 02 2016 Vít Ondruch <vondruch@redhat.com> - 1.8.1-2
- Fix plugin installation error (rhbz#1330208).

* Tue Feb 09 2016 Tomas Hrcka <thrcka@redhat.com> - 1.8.1-1
- New upstream release
- Disable tests using winrm

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Feb 01 2016 Vít Ondruch <vondruch@redhat.com> - 1.7.4-5
- Use another way how to make the documentation to generate.

* Mon Feb 01 2016 Vít Ondruch <vondruch@redhat.com> - 1.7.4-4
- Update the macros to keep them in sync with rubygems package.

* Wed Oct 14 2015 Josef Stribny <jstribny@redhat.com> - 1.7.4-3
- Fix: Don't use biosdevname if missing in Fedora guest

* Tue Oct 13 2015 Vít Ondruch <vondruch@redhat.com> - 1.7.4-2
- Fix Bundler 1.10.6 compatibility.
- Recommends vagrant-libvirt installation by default.

* Thu Aug 20 2015 Josef Stribny <jstribny@redhat.com> - 1.7.4-1
- Update to 1.7.4
- Patch: install plugins in isolation

* Fri Jul 10 2015 Dan Williams <dcbw@redhat.com> - 1.7.2-9
- Allow matching interfaces on MAC address

* Tue Jun 30 2015 Josef Stribny <jstribny@redhat.com> - 1.7.2-8
- Fix NFS on Fedora

* Tue Jun 16 2015 Josef Stribny <jstribny@redhat.com> - 1.7.2-7
- Fix: Remove docker0 from guest network interface enumeration

* Thu May 21 2015 Josef Stribny <jstribny@redhat.com> - 1.7.2-6
- Fix: Support new Fedora releases
- Fix: Don't try to use biosdevname if it's not installed

* Wed May 06 2015 Josef Stribny <jstribny@redhat.com> - 1.7.2-5
- Export GEM_HOME based on VAGRANT_HOME

* Tue May 05 2015 Josef Stribny <jstribny@redhat.com> - 1.7.2-4
- Include $USER path in binstub

* Fri Feb 20 2015 Vít Ondruch <vondruch@redhat.com> - 1.7.2-3
- Fix Puppet provisioning error available in 1.7.2 re-release.

* Fri Feb 20 2015 Michael Adam <madam@redhat.com> - 1.7.2-2
- Add missing dependencies.

* Thu Feb 12 2015 Tomas Hrcka <thrcka@redhat.com> - 1.7.2-1
- Update to latest upstream version 1.7.2
- Backport dependencies fix patch
- Remove permissions fix on mkdir.rb

* Mon Jan 26 2015 Vít Ondruch <vondruch@redhat.com> - 1.6.5-18
- Prepare and own plugin directory structure.

* Thu Jan 22 2015 Michael Adam <madam@redhat.com> - 1.6.5-17
- Fix %%check in an unclean build environment.
- Fix typo.

* Tue Jan 20 2015 Vít Ondruch <vondruch@redhat.com> - 1.6.5-16
- Minor review fixes.

* Tue Dec 23 2014 Vít Ondruch <vondruch@redhat.com> - 1.6.5-15
- Relax thor dependency to keep up with Fedora.

* Wed Nov 26 2014 Vít Ondruch <vondruch@redhat.com> - 1.6.5-14
- Drop -devel sub-package.

* Tue Nov 25 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-13
- Create -devel sub-package

* Mon Nov 24 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-12
- Include monkey-patching for RubyGems and Bundler for now

* Wed Oct 22 2014 Vít Ondruch <vondruch@redhat.com> - 1.6.5-11
- Make vagrant non-rubygem package.

* Tue Oct 14 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-10
- rebuilt

* Tue Oct 07 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-9
- Register vagrant-libvirt automatically

* Tue Sep 30 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-8
- Set libvirt as a default provider

* Tue Sep 23 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-7
- Require core dependencies for vagrant-libvirt beforehand

* Mon Sep 22 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-6
- Fix SSL cert path for the downloader

* Tue Sep 16 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-5
- rebuilt

* Tue Sep 16 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-4
- rebuilt

* Sat Sep 13 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-3
- Include libvirt requires for now

* Wed Sep 10 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-2
- Add missing deps on Bundler and hashicorp-checkpoint

* Mon Sep 08 2014 Josef Stribny <jstribny@redhat.com> - 1.6.5-1
* Update to 1.6.5

* Mon Sep 08 2014 Josef Stribny <jstribny@redhat.com> - 1.6.3-2
- Clean up
- Update to 1.6.3

* Fri Oct 18 2013  <adrahon@redhat.com> - 1.3.3-1.1
- Misc bug fixes, no separate package for docs, /etc/vagrant management

* Tue Sep 24 2013  <adrahon@redhat.com> - 1.3.3-1
- Initial package
